@@ -5,7 +5,13 @@ use warnings;
 use base qw( Alien::Base );
 
 # ABSTRACT: Build and make available Editline (libedit)
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
+
+
+
+
+
+
 
 
 1;
@@ -22,17 +28,20 @@ Alien::Editline - Build and make available Editline (libedit)
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
-In your C<Build.PL>:
+In your Build.PL:
 
- use Alien::Editline;
  use Module::Build;
- 
- my $build = Module::Build->new(
+ use Alien::Editline;
+ my $builder = Module::Build->new(
    ...
+   configure_requires => {
+     'Alien::Editline' => '0',
+     ...
+   },
    extra_compiler_flags => Alien::Editline->cflags,
    extra_linker_flags   => Alien::Editline->libs,
    ...
@@ -40,13 +49,30 @@ In your C<Build.PL>:
  
  $build->create_build_script;
 
-In your L<FFI::Raw> script:
+In your Makefile.PL:
 
+ use ExtUtils::MakeMaker;
+ use Config;
  use Alien::Editline;
- use FFI::Raw;
  
- my($dll) = Alien::Editline->dynamic_libs;
- FFI::Raw->new($dll, '...', ...);
+ WriteMakefile(
+   ...
+   CONFIGURE_REQUIRES => {
+     'Alien::Editline' => '0',
+   },
+   CCFLAGS => Alien::Editline->cflags . " $Config{ccflags}",
+   LIBS    => [ Alien::Editline->libs ],
+   ...
+ );
+
+In your L<FFI::Platypus> script or module:
+
+ use FFI::Platypus;
+ use Alien::Editline;
+ 
+ my $ffi = FFI::Platypus->new(
+   lib => [ Alien::Editline->dynamic_libs ],
+ );
 
 =head1 DESCRIPTION
 
@@ -55,6 +81,10 @@ installed for your operating system, and it can be found, this distribution will
 that comes with your operating system, otherwise it will download it from the Internet, build and
 install it fro you.
 
+=head1 SEE ALSO
+
+L<Alien>, L<Alien::Base>, L<Alien::Build::Manual::AlienUser>
+
 =head1 AUTHOR
 
 Graham Ollis <plicease@cpan.org>
